==> qmmp-0.12.20.tar.bz2: qmmp-0.12.20/src/plugins/General/covermanager/translations/covermanager_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>CoverManager</name>
    <message>
        <location filename="../covermanager.cpp" line="35"/>
        <source>Show Cover</source>
        <translation>Tampakkan Sampul</translation>
    </message>
    <message>
        <location filename="../covermanager.cpp" line="36"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
</context>
<context>
    <name>CoverManagerFactory</name>
    <message>
        <location filename="../covermanagerfactory.cpp" line="30"/>
        <source>Cover Manager Plugin</source>
        <translation>Plugin Manager Cover</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="50"/>
        <source>About Cover Manager Plugin</source>
        <translation>Tentang Plugin Manager Cover</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="51"/>
        <source>Qmmp Cover Manager Plugin</source>
        <translation>Plugin Manager Cover Qmmp</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>CoverWidget</name>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Simpan Sebagai...</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="38"/>
        <source>Size</source>
        <translation>Ukuran</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="40"/>
        <source>Actual Size</source>
        <translation>Ukuran Sebenarnya</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="41"/>
        <source>128x128</source>
        <translation>128x128</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="42"/>
        <source>256x256</source>
        <translation>256x256</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="43"/>
        <source>512x512</source>
        <translation>512x512</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="44"/>
        <source>1024x1024</source>
        <translation>1024x1024</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>&amp;Close</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>Alt+F4</source>
        <translation>Alt+F4</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="90"/>
        <source>Save Cover As</source>
        <translation>Simpan Sampul Sebagai</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="92"/>
        <source>Images</source>
        <translation>Citra</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/General/covermanager/translations/covermanager_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>CoverManager</name>
    <message>
        <location filename="../covermanager.cpp" line="35"/>
        <source>Show Cover</source>
        <translation>Tampakkan Sampul</translation>
    </message>
    <message>
        <location filename="../covermanager.cpp" line="36"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
</context>
<context>
    <name>CoverManagerFactory</name>
    <message>
        <location filename="../covermanagerfactory.cpp" line="30"/>
        <source>Cover Manager Plugin</source>
        <translation>Plugin Manager Cover</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="50"/>
        <source>About Cover Manager Plugin</source>
        <translation>Tentang Plugin Manager Cover</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="51"/>
        <source>Qmmp Cover Manager Plugin</source>
        <translation>Plugin Manager Cover Qmmp</translation>
    </message>
    <message>
        <location filename="../covermanagerfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CoverWidget</name>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Simpan Sebagai...</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="37"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="38"/>
        <source>Size</source>
        <translation>Ukuran</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="40"/>
        <source>Actual Size</source>
        <translation>Ukuran Sebenarnya</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="41"/>
        <source>128x128</source>
        <translation>128x128</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="42"/>
        <source>256x256</source>
        <translation>256x256</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="43"/>
        <source>512x512</source>
        <translation>512x512</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="44"/>
        <source>1024x1024</source>
        <translation>1024x1024</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>&amp;Close</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="47"/>
        <source>Alt+F4</source>
        <translation>Alt+F4</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="90"/>
        <source>Save Cover As</source>
        <translation>Simpan Sampul Sebagai</translation>
    </message>
    <message>
        <location filename="../coverwidget.cpp" line="92"/>
        <source>Images</source>
        <translation>Citra</translation>
    </message>
</context>
</TS>
